.. _data_model:

Data Models
===========

This section is a collection of concepts or notations for describing the
structure of the ScanCode.io Data Model and providing details about all fields
included in the output files.

Project
-------
.. autoclass:: scanpipe.models.Project()
    :members:
    :undoc-members:
    :member-order: groupwise

CodebaseResource
----------------
.. autoclass:: scanpipe.models.CodebaseResource()
    :members:
    :undoc-members:
    :member-order: groupwise

DiscoveredPackage
-----------------
.. autoclass:: scanpipe.models.DiscoveredPackage()
    :members:
    :undoc-members:
    :member-order: groupwise

DiscoveredDependency
--------------------
.. autoclass:: scanpipe.models.DiscoveredDependency()
    :members:
    :undoc-members:
    :member-order: groupwise

CodebaseRelation
----------------
.. autoclass:: scanpipe.models.CodebaseRelation()
    :members:
    :undoc-members:
    :member-order: groupwise

ProjectMessage
--------------
.. autoclass:: scanpipe.models.ProjectMessage()
    :members:
    :undoc-members:
    :member-order: groupwise

Run
---
.. autoclass:: scanpipe.models.Run()
    :members:
    :undoc-members:
    :member-order: groupwise
